// file mainServer.cc
// Author: Alberto D'Angeli

#include <CORBA.h>
#include <coss/CosNaming.h>
#include "CalcolatriceImpl.h"
#include <iostream>
#include <fstream> 

using namespace std;

int main(int argc, char* argv[])
{

 try {

    // Initialize the ORB.
    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
    cout << "Initialized the ORB" << endl;
        
    // get a reference to the root POA
    CORBA::Object_var obj = orb->resolve_initial_references("RootPOA");
    PortableServer::POA_var rootPOA = PortableServer::POA::_narrow(obj.in());
    cout << "got a reference to the root POA" << endl;
    
    // get the POA Manager
    PortableServer::POAManager_var poa_manager = rootPOA->the_POAManager();
    cout << "got the POA Manager" << endl;

           
    // get a reference to the Naming Service root_context
	    CosNaming::NamingContext_var rootContext = CosNaming::NamingContext::_narrow(orb->resolve_initial_references("NameService"));
    cout << "got a reference to root NC!" << endl;

       
    // Object #1
    // Create the servant
    CalcolatriceImpl managerServant;
    cout << "Created the servant" << endl;

    // Activate the object
    PortableServer::ObjectId_var oid = rootPOA->activate_object(&managerServant);
    cout << "Activated the servant on rootPOA" << endl;
    
    // Get object reference
    CORBA::Object_var ref = rootPOA->id_to_reference(oid.in());
       
    // Associate the calcolatrice object with the name at the root context
    CosNaming::Name name;
    name.length(1);
    name[0].id = (const char *) "eai";
    name[0].kind = (const char *) "";
      
    CosNaming::NamingContext_var nc1;
    try
    {
       nc1 = rootContext -> bind_new_context(name);
    }
    catch(const CosNaming::NamingContext::AlreadyBound&)
    {
       // OK, our naming context had already been created, so we just need to resolve it !
       CORBA::Object_var obj = rootContext->resolve(name);
       nc1 = CosNaming::NamingContext::_narrow(obj.in());
    }
    name.length(2);
    name[0].id = (const char *) "eai";
    name[0].kind = (const char *) "";
    name[1].id = (const char *) "calcolatrice";
    name[1].kind = (const char *) "";
    rootContext->rebind(name, ref.in());
      
       
    // Activate the POA Manager
    poa_manager->activate();
    cout << "Activate the POA Manager" << endl;
    // Wait for incoming requests
    orb->run();
  }
  catch(const CORBA::Exception& e) {
	  cout << "eccezione!!! " << endl;
    cout << e << endl;
    return 1;
  }
  return 0;
}

