import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

import it.mokabyte.eai.my.config.ConfiguratorBean;
/**
 * <p>Title: ConfiguratorConsole</p>
 * <p>Description: Configurator console</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author S: Rossini
 * @version 1.0
 */
public class ConfiguratorConsole extends JFrame {

  /* Componenti interfaccia grafica */
  /** Current dir */
  private String currentDir = null;
  /** Complete File name */
  private String fileName = null;
  /** File extension (.bet or .sh) */
  private String extension = null;
  /** File */
  private File file = null;
  /** Il bottone per il clear del messaggio da inviare */
  private JButton bClear = null;
  /** Il bottone per inviare il messagggio */
  private JButton bCommit = null;
  /** Il bottone per uscire senza salvare */
  private JButton bCancel = null;
  /** Il bottone di HELP ON LINE */
  private JButton bHelpOnLine = null;
  /** La TextField per inserire i nomi degli Host */
  private JTextField[] tfHost = null;
  /** La TextField per inserire i valori delle variabili d'ambiente */
  private JTextField[] tfEnv = null;
  /** Logo file name */
  private static final String LOGO_FILE_NAME = "images/moka_eai_logo.gif";
  /** Environment settings */
  private static final String[] strEnv = {
      "JAVA_HOME",
      "ANT_HOME",
      "JBOSS_DIST",
      "TOMCAT_HOME",
      "WLS_HOME",
      "AXIS_DIST",
      "AXIS_PATH",
      "MICO_HOME",
      "GSOAP_HOME",
      "DOTNET_DIST"
  };

  /** Label Host values */
  private static final String[] strHost = {
      "HOST_A (TOMCAT)[8080]:",
      "HOST_B (WLS)[7001]:",
      "HOST_C (IIS)[80]:",
      "HOST_D (MICO)[1666]-(SUN)[2000]:",
      "HOST_E (TOMCAT-AXIS)[8080]:",
      "HOST_F (GSOAP)[1888]:"
  };
  /** SET to write into file */
  String[] strHosts = {
      "HOST_A",
      "HOST_B",
      "HOST_C",
      "HOST_D",
      "HOST_E",
      "HOST_F"
  };
  /** Font*/
  private static Font font = new Font("Arial", Font.BOLD, 16);
  /** Titolo Frame & Message Dialog */
  private static final String TITLE = "Configurator Console 1.0";
  /** enable/disable INTERNAL Debug */
  private static final boolean DEBUG = true;
  /** enable/disable INTERNAL Deep Debug */
  private static final boolean DEEP_DEBUG = false;

  /**
   * Metodo main
   * @param args  i nomi JNDI del topic connection factory e del topic d'interesse (opzionali)
   */
  public static void main(String[] args) {
    new ConfiguratorConsole().go();
  }

  /**
   * Costruttore
   * @param topicConnectionFactoryName JNDI name del Connection Factory
   * @param topicName JNDI name del topic
   */
  public ConfiguratorConsole() {
    super(TITLE);
    this.currentDir = System.getProperty("user.dir");

    if (System.getProperty("os.name").startsWith("Windows")) {
      this.extension = ".bat";
    }
    else {
      this.extension = ".sh";
    }
    System.out.println("Configurator: currentDir["+this.currentDir+"]...");
    System.out.println("Configurator: extension["+this.extension+"]...");
  }

  /**
   * Avvio configurazione
   */
  public void go() {

    System.out.println("ConfiguratorConsole: go...");

    try {
      System.out.println("ConfiguratorConsole: buildGUI...");
      this.buildGUI();

      System.out.println("ConfiguratorConsole: loading environment...");
      this.loadFileEnv();
    }
    catch (Exception ex) {
      System.out.println("Configurator.go: # Exception # :" + ex.getMessage());
      ex.printStackTrace();
      javax.swing.JOptionPane.showMessageDialog(null, ex.getMessage(), TITLE,
                                                javax.swing.JOptionPane.
                                                ERROR_MESSAGE);
    }
  }

  /**
   * Costruzione dell'interfaccia grafica
   */
  private void buildGUI() {

    // inizializzazione componenti GUI
    tfEnv = new JTextField[strEnv.length];
    tfHost = new JTextField[strHost.length];

    for (int i = 0; i < strHost.length; ++i) {
      tfHost[i] = new JTextField();
      // tfHost[i].setFont(font);
      tfHost[i].setText("localhost");
    }

    // pulsanti
    bClear = new JButton("CLEAR");
    bCommit = new JButton("COMMIT");
    bCancel = new JButton("EXIT");
    bHelpOnLine = new JButton("HELP");

    // Logo
    System.out.println("Configurator: loading image[" + LOGO_FILE_NAME + "]...");
    ImageIcon img = new ImageIcon(LOGO_FILE_NAME);
    JLabel picture = new JLabel(img);

    // Layout: Num righe host + num righe env + 3(per i bottoni e le due intestazioni)
    int numRighe = strHost.length + strEnv.length + 3;
    int numCols = 2;
    System.out.println("Configurator: rows["+numRighe+"]-cols["+numCols+"]...");
    JPanel p = new JPanel();
    p.setLayout(new GridLayout(numRighe, numCols, 10, 10));

    Label lbl = null;
    // Header
    lbl = new Label("ENV");
    lbl.setFont(font);
    p.add(lbl);
    lbl = new Label("VAL");
    lbl.setFont(font);
    p.add(lbl);

    // ENV
    for (int i = 0; i < strEnv.length; ++i) {
      tfEnv[i] = new JTextField("");
    }

    for (int i = 0; i < strEnv.length; ++i) {
      p.add(new Label(strEnv[i]));
      p.add(tfEnv[i]);
    }

    // Header
    lbl = new Label("HOST Name/IP [TCP PORT]");
    lbl.setFont(font);
    p.add(lbl);
    lbl = new Label("VALORE HOST");
    lbl.setFont(font);
    p.add(lbl);

    // HOST
    for (int i = 0; i < strHost.length; ++i) {
      p.add(new Label(strHost[i]));
      p.add(tfHost[i]);
    }

    // p.add(bClear);
    p.add(bHelpOnLine);
    p.add(bCommit);

    // ADD to contentPane
    this.getContentPane().add(picture, BorderLayout.NORTH);
    this.getContentPane().add(p, BorderLayout.CENTER);
    this.getContentPane().add(bCancel, BorderLayout.SOUTH);

    // il bottone send invia il messaggio contenuto nel TextField
    bCommit.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {

        // avvia la congigurazione
        autoMagicallyConfiguration();
      }
    });

    // il bottone clear ripulisce la TextField
    bClear.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        for (int i = 0; i < strHosts.length; ++i) {
          tfHost[i].setText("");
        }
      }
    });

    // il bottone cancel esce dal programma
    bCancel.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        System.exit( -1);
      }
    });

    // il bottone di HELP ON LINE
    bHelpOnLine.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {

        String msg = "O.S: " + System.getProperty("os.name") + "\nWORK_DIR: " +
            currentDir + "\n" +
            "Inserire il valore delle variabili d'ambiente d'interesse\n"+
            "Inserire il nome o l'indirizzo IP delle macchine Server(localhost per la macchina locale)\n"+
            "Per il deploy eseguire il batch [" + currentDir + File.separator+"ant"+File.separator+"deployer"+extension+"]\n" +
            "I batch di test sono nella directory [" + currentDir +File.separator+"batch]\n"+
            "La documentazione e' disponibile in [" + currentDir + File.separator+"doc]\n" +
            "BUON LAVORO!\n";
        javax.swing.JOptionPane.showMessageDialog(null, msg, "Console Config",
                                                  javax.swing.JOptionPane.
                                                  INFORMATION_MESSAGE);
      }
    });

    // l'evento di chiusura della finestra genera la chiusura della connessione JMS
    this.addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e) {
        System.out.println("windowClosing : ...");
        System.exit(0);
      }
    });

    // Dimensioni e posizionamento
    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    this.setSize(screenSize.width * 2 / 3, screenSize.height * 3 / 4);
    Dimension frameSize = this.getSize();
    this.setLocation( (screenSize.width - frameSize.width) / 2,
                     (screenSize.height - frameSize.height) / 2);

    System.out.println("Configurator: content pane[" +
                       this.getContentPane().getLayout());
    this.setVisible(true);
  }

    /**
   * Load File ENVIRONMENT
   */
  private void loadFileEnv() {

    File file = null;
    FileInputStream fis = null;
    Properties p = null;

    file = new File("environment.properties");
    System.out.println("ConfiguratorBean.loadFileEnv: il file["+file.getAbsolutePath()+"] esiste...");

    if (!file.exists()) {
      String err=" # ERROR # File["+file.getAbsolutePath()+"] NON ESISTE !";
      javax.swing.JOptionPane.showMessageDialog(null, err, TITLE,
                                                javax.swing.JOptionPane.
                                                ERROR_MESSAGE);
      System.out.println("Configurator.loadFileEnv: " + err);
    }

    try {
      System.out.println("Configurator.loadFileEnv: il file["+file.getAbsolutePath()+"] esiste...");
      p = new Properties();
      fis = new FileInputStream(file);
      p.load(fis);
      System.out.println("Configurator.loadFileEnv: props["+p+"] read from file prop ...");
      if (p == null) {
        String err=" # ERROR # File["+file.getAbsolutePath()+"] ESISTE MA CORROTTO !";
        javax.swing.JOptionPane.showMessageDialog(null, err, TITLE,
                                                  javax.swing.JOptionPane.
                                                  ERROR_MESSAGE);
        System.out.println("Configurator.loadFileEnv: " + err);
      }

      for (int i = 0; i < strHosts.length; ++i) {
        System.out.println("Configurator: loading for ["+strHosts[i]+"] value["+ p.getProperty(strHosts[i])+"]...");
        if (p.getProperty(strHosts[i]) != null) {
          tfHost[i].setText(p.getProperty(strHosts[i]));
        }
      }
      for (int i = 0; i < strEnv.length; ++i) {
        System.out.println("Configurator: loading for ["+strEnv[i]+"] value["+ p.getProperty(strEnv[i])+"]...");
        if (p.getProperty(strEnv[i]) != null) {
          tfEnv[i].setText(p.getProperty(strEnv[i]));
        }
      }

      fis.close();
    }
    catch (Exception e) {
      System.out.println("Configurator: # Exception # :" + e.getMessage());
    }
    finally {
      if (fis != null) {
        try {
          fis.close();
        }
        catch (Exception e) {}
      }
    }
  }

  /**
   * autoMagicallyConfiguration: configuration core
   */
  private void autoMagicallyConfiguration() {

    File inputFile = null;
    File outputFile = null;
    BufferedReader br = null;

    try {

      System.out.println("\n\t>>> STEP 1: CHECK envinroment ...");

      // First of all: CHECK Enironment values ...
      for (int i = 0; i < strEnv.length; ++i) {
        System.out.println("Configurator.autoMagicallyConfiguration: CHECK FOR["+tfEnv[i].getText()+"]...");
        if(!tfEnv[i].getText().equals("") && !new File(tfEnv[i].getText()).exists()){
          String msg="Valore ["+tfEnv[i].getText()+"] ERRATO della variabile ["+strEnv[i]+"] !";
          javax.swing.JOptionPane.showMessageDialog(null,
              msg,
              "Console Config",
              javax.swing.JOptionPane.INFORMATION_MESSAGE);
          return;
        }
      }

      new ProgressMonitorDemo().go();

    }catch (Exception ex) {
      javax.swing.JOptionPane.showMessageDialog(null, ex.getMessage(),
                                                "Console Config",
                                                javax.swing.JOptionPane.ERROR_MESSAGE);
      ex.printStackTrace();
    }
  }

  /**
     * createScriptFile
     * @param inputFile
     * @param outputFile
     */
   private void createScriptFile(File inputFile, File outputFile) throws java.io.IOException{

     PrintWriter pw = null;
     BufferedReader br = null;
     String text = null;

     System.out.println("Configurator.createScriptFile: <<< input file["+inputFile.getAbsolutePath()+"]...");
     System.out.println("Configurator.createScriptFile: >>> output file["+outputFile.getAbsolutePath()+"]...");

     if (outputFile.exists()) {
       outputFile.delete();
     }
     pw = new PrintWriter(new BufferedWriter(new FileWriter(outputFile)));

     if (System.getProperty("os.name").startsWith("Windows")) {
       pw.println("rem " + new java.util.Date().toString() +
                  ": AUTOGENERATED by ConfiguratorConsole MOKA EAI");
     }
     else {
       pw.println("# " + new java.util.Date().toString() +
                  ": AUTOGENERATED by ConfiguratorConsole MOKA EAI ...");
     }
     pw.flush();

     if (System.getProperty("os.name").startsWith("Windows")) {
       pw.println("SET WORK_DIR=" + currentDir);
       pw.println("SET MY_CLASSES=" + currentDir + File.separator +
                  "classes");
     }
     else {
       pw.println("export WORK_DIR=" + currentDir);
       pw.println("export MY_CLASSES=" + currentDir + File.separator +
                  "classes");
     }
     pw.flush();
     for (int i = 0; i < strHosts.length; ++i) {
       if (System.getProperty("os.name").startsWith("Windows")) {
         pw.println("SET " + strHosts[i] + "=" + tfHost[i].getText());
       }
       else {
         pw.println("export " + strHosts[i] + "=" + tfHost[i].getText());
       }
       pw.flush();
     }
     for (int i = 0; i < strEnv.length; ++i) {
       if (System.getProperty("os.name").startsWith("Windows")) {
         pw.println("SET " + strEnv[i] + "=" + tfEnv[i].getText());
       }
       else {
         pw.println("export " + strEnv[i] + "=" + tfEnv[i].getText());
       }
       pw.flush();
     }

     br = new BufferedReader(new FileReader(inputFile));
     while ( (text = br.readLine()) != null) {
       if (DEEP_DEBUG) System.out.println(text);
       pw.println(text);
       pw.flush();
     }
     br.close();
     pw.close();
   }

  /**
   * createPropertiesFile
   * @param file
   * @throws java.io.IOException
   */
  void createPropertiesFile(File file, boolean b) throws java.io.IOException{

    PrintWriter pw =null;
    String text=null;

    if (file.exists())file.delete();
    System.out.println("Configurator.createPropertiesFile: file["+file.getAbsolutePath()+"]...");
    pw = new PrintWriter(new BufferedWriter(new FileWriter(file.getAbsolutePath(),file.exists())));
    if(DEBUG) System.out.println("Configurator: currentDir["+currentDir+"]...");
    if(b){
      if (System.getProperty("os.name").startsWith("Windows")) {
        String winCurrentDir = java.util.regex.Pattern.compile("\\\\").matcher(this.
            currentDir).replaceAll("\\\\\\\\");
        pw.println("WORK_DIR=" + winCurrentDir);
        pw.flush();
      }
      else {
        pw.println("WORK_DIR=" + this.currentDir);
        pw.flush();
      }
    }
    for (int i = 0; i < strHosts.length; ++i) {
        pw.println(strHosts[i] + "=" + tfHost[i].getText());
        pw.flush();
    }

    for(int i=0; i<strEnv.length; ++i){
      if (System.getProperty("os.name").startsWith("Windows")) {
        String winEnv = java.util.regex.Pattern.compile("\\\\").matcher(tfEnv[i].getText()).replaceAll("\\\\\\\\");
        pw.println(strEnv[i] + "=" + winEnv);
        pw.flush();
      }
      else {
        pw.println(strEnv[i] + "=" + tfEnv[i].getText());
        pw.flush();
      }
    }
    pw.close();
  }

  /**
     * copyFile
     * @param inputFile
     * @param outputFile
     */
   private void copyFile(File inputFile, File outputFile) throws java.io.IOException{

     PrintWriter pw = null;
     BufferedReader br = null;
     String text = null;

     System.out.println("Configurator.copyFile: <<< input file["+inputFile.getAbsolutePath()+"]...");
     System.out.println("Configurator.copyFile: >>> output file["+outputFile.getAbsolutePath()+"]...");

     if (outputFile.exists()) {
       outputFile.delete();
     }
     pw = new PrintWriter(new BufferedWriter(new FileWriter(outputFile)));

     br = new BufferedReader(new FileReader(inputFile));
     while ( (text = br.readLine()) != null) {
       if (DEEP_DEBUG) System.out.println(text);
       pw.println(text);
       pw.flush();
     }
     br.close();
     pw.close();
   }

  /**
   * callExec
   * @throws java.io.IOException
   * @throws InterruptedException
   */
  private int callExec() throws java.io.IOException,InterruptedException {

    BufferedReader br = null;

    // =====< EXEC Builder BAT / Shell >=====
    String cmd = currentDir + "/ant/builder" + this.extension;
    System.out.println("Configurator: executing [" + cmd + "]...");

    File f = new File(cmd);
    if (!f.exists()) {
      System.out.println("Configurator: # ERROR # File[" +
                             f.getAbsolutePath() + "] NON ESISTE!");
    }
    else {
      if (DEBUG) System.out.println("Configurator: FILE[" + f.getAbsolutePath() +
                               "] esiste...");
    }

    if(DEBUG) System.out.println("Configurator: FILE[" + f.getAbsolutePath() +
                               "] in esecuzione ...");
    // start command running
    Process proc = Runtime.getRuntime().exec(cmd);
    // get command's output stream and put a buffered reader input stream on it
    InputStream istr = proc.getInputStream();
    br = new BufferedReader(new InputStreamReader(istr));
    // set up list to capture command output lines
    ArrayList list = new ArrayList();
    // read output lines from command
    String str;
    while ( (str = br.readLine()) != null) {
      if (DEBUG)System.out.println(str);
      list.add(str);
    }

    // wait for command to terminate
    if (DEBUG) System.out.println("Executor.runCommand : BEFORE waiting process's end ...");
    proc.waitFor();
    if (DEBUG)System.out.println("Executor.runCommand : process OVER!");

    System.out.println("Configurator: esecuzione["+f.getAbsolutePath()+"] avvenuta...");

    // dump file executed
    String[] res = ( (String[]) list.toArray(new String[0]));
    for (int i = 0; i < res.length; ++i) {
      if (DEEP_DEBUG)System.out.println("" + res[i]);
    }
    return proc.exitValue();

  }

  /**
  * createPropertiesFile
  * @param file
  * @throws java.io.IOException
  */
  private boolean setHostIntoWsdlFile(File fileWSDLRD,File fileWSDLWR) throws java.io.IOException{

    String TOKEN = "localhost";
    boolean retVal = false;
    String text = null;

    if (fileWSDLWR.exists()){
      fileWSDLWR.delete();
    }

    if (fileWSDLRD.exists()){
      if(DEBUG) System.out.println("Configurator.setHostIntoWsdlFile: file["+fileWSDLRD.getAbsolutePath()+"] esiste ...");
      PrintWriter pw = new PrintWriter(new BufferedWriter(new FileWriter(
                                         fileWSDLWR.getAbsolutePath(), fileWSDLWR.exists())));
      BufferedReader br = new BufferedReader(new FileReader(fileWSDLRD));
      while ( (text = br.readLine()) != null) {
        if (DEEP_DEBUG) System.out.println(text);
        if (text.indexOf(TOKEN) > -1) {
          if(DEEP_DEBUG) System.out.println("Configurator.setHostIntoWsdlFile: toke[" + TOKEN +
                             "] found in [" + text + "]...");
          text=java.util.regex.Pattern.compile(TOKEN).matcher(text).replaceAll(
                                               tfHost[strHost.length - 1].getText());
          if(DEBUG) System.out.println("Configurator.setHostIntoWsdlFile: new text is[" +
                             text + "]...");
          pw.println(text);
          pw.flush();
          retVal=true;
        }
        else{
          pw.println(text);
          pw.flush();
        }
      }
      pw.close();
      br.close();
    }
    else{
      if(DEBUG) System.out.println("Configurator.setHostIntoWsdlFile: file["+fileWSDLRD.getAbsolutePath()+"] #NON# esiste ...");
    }
    System.out.println("Configurator.setHostIntoWsdlFile: return["+retVal+"]...");
    return retVal;
 }

 /**
  * <p>Title: ProgressMonitorDemo</p>
  * <p>Description: finestra di stato avanzamento configurazione</p>
  * <p>Copyright: Copyright (c) 2002</p>
  * <p>Company: </p>
  * @authorS. Rossini
  * @version 1.0
  */
 class ProgressMonitorDemo extends JFrame {

   public final static int ONE_SECOND = 1000;

   private ProgressMonitor progressMonitor;
   private JTextArea ta;
   private JProgressBar progressBar;
   private JLabel label;

   public ProgressMonitorDemo() {

     super("ProgressMonitorDemo");

     this.ta = new JTextArea(5, 20);
     ta.setMargin(new Insets(5,5,5,5));
     ta.setEditable(false);
     Font font = new Font("Arial", Font.BOLD, 15);
     ta.setFont(font);

     this.progressBar=new JProgressBar();

     this.label = new JLabel("  0%");
     this.label.setEnabled(false);
     Font font2 = new Font("Arial", Font.BOLD, 22);
     this.label.setFont(font2);

     JPanel panel = new JPanel();
     panel.setLayout(new BorderLayout());
     panel.add(progressBar, BorderLayout.CENTER);
     panel.add(this.label,BorderLayout.WEST);
     this.getContentPane().add(panel,BorderLayout.NORTH);

     JPanel panel2 = new JPanel();
     panel2.setLayout(new BorderLayout());
     panel2.add(new JScrollPane(ta), BorderLayout.CENTER);
     panel2.setBorder(BorderFactory.createEmptyBorder(20, 20, 20, 20));
     this.getContentPane().add(panel2,BorderLayout.CENTER);

     progressMonitor = new ProgressMonitor(ProgressMonitorDemo.this,
                           "Running a Long Task",
                           "", 0, 100);
     progressMonitor.setProgress(0);
     progressMonitor.setMillisToDecideToPopup(2 * 1000);

     // Dimensioni e posizionamento
     Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
     this.setSize((screenSize.width / 5) * 4, (screenSize.height / 3)*2);
     Dimension frameSize = this.getSize();
     this.setLocation( (screenSize.width - frameSize.width) / 2,
                   (screenSize.height - frameSize.height) / 2);

     this.setVisible(true);
   }

   public void go(){
       new ConfiguratorMasterThread(this.progressBar,this.ta,this.label).start();
   }
 }

 /**
  * <p>Title: ConfiguratorMasterThread</p>
  * <p>Description: Thread principale che coordinai singoli Thread di configurazione</p>
  * <p>Copyright: Copyright (c) 2002</p>
  * <p>Company: </p>
  * @authorS. Rossini
  * @version 1.0
  */
 class ConfiguratorMasterThread extends Thread{

  private JProgressBar bar = null;
  private JTextArea ta = null;
  private JLabel label=null;

  /**
   * Costruttore: riceve gli oggetti grafici da aggiornare
   * @param bar
   * @param ta
   */
  public ConfiguratorMasterThread(JProgressBar bar,JTextArea ta, JLabel label){
    System.out.println("ConfiguratorMasterThread:...");
    this.bar = bar;
    this.ta=ta;
    this.label=label;
  }

  /**
   * Il corpo del Thread che esegue step by step la configurazione
   * <li>
   */
  public void run() {

    try {
       String LF = System.getProperty("line.separator");

       // =====< SETENV - BAT / SHELL >=====
       this.ta.append("1) creazioned del file ant"+file.separator+"setenv"+extension+LF);
       File inputFile = new File(currentDir + "/ant/_template"+extension);
       File outputFile = new File(currentDir + "/ant/setenv_eai"+extension);
       SwingUtilities.invokeAndWait(new KreatorScriptFileThread(inputFile,outputFile));
       updateBar(5);

       this.ta.append("2) creazioned del file setenv."+extension+LF);
       outputFile = new File(currentDir + "/setenv_eai"+extension);
       SwingUtilities.invokeAndWait(new KreatorScriptFileThread(inputFile,outputFile));
       updateBar(10);

       // =====< PROPERTIES >=====
       this.ta.append("3) creazione del file setenv_eai"+extension+" sotto classes..."+LF);
       File f = new File(currentDir+File.separator+"classes"+File.separator+"setenv_eai.properties");
       SwingUtilities.invokeAndWait(new KreatorPropertiesFileThread(f,true));
       updateBar(15);

       this.ta.append("4) creazione del file setenv_eai"+extension+" sotto classes/it/mokabyte/..."+LF);
       f = new File(currentDir+File.separator+"classes"+
                         File.separator+"it"+
                         File.separator+"mokabyte"+
                         File.separator+"eai"+
                         File.separator+"my"+
                         File.separator+"config"+
                         File.separator+"setenv_eai.properties");
       SwingUtilities.invokeAndWait(new KreatorPropertiesFileThread(f,true));
       updateBar(20);

       this.ta.append("5) creazione/update del file environment.properties..."+LF);
       f=new File(currentDir+File.separator+"environment.properties");
       SwingUtilities.invokeAndWait(new KreatorPropertiesFileThread(f,false));
       updateBar(25);

       // ======< WSDL >=====
       // AXIS
       this.ta.append("6) sostituzione localhost con HOST_E in MokaCalculatorService.xml..."+LF);
       File fileWSDLRD = new File(currentDir + File.separator + "interfaces" +
                                  File.separator + "wsdl" + File.separator + "axis" +
                                  File.separator + "MokaCalculatorService.xml");

       File fileWSDLWR = new File(currentDir + File.separator + "interfaces" +
                                  File.separator + "wsdl" + File.separator + "axis" +
                                  File.separator + "AxisCalculatorService.wsdl");

       SwingUtilities.invokeAndWait(new SetterHostIntoWsdlFileThread(fileWSDLRD,fileWSDLWR));
       updateBar(30);

       // .NET
       this.ta.append("7) sostituzione localhost con HOST_E in Calculator.asmx..."+LF);
       fileWSDLRD = new File(currentDir + File.separator + "interfaces" +
                                  File.separator + "wsdl" + File.separator + "dotnet" +
                                  File.separator + "Calculator.asmx");

       fileWSDLWR = new File(currentDir + File.separator + "interfaces" +
                                  File.separator + "wsdl" + File.separator + "dotnet" +
                                  File.separator + "DotNetCalculatorService.wsdl");
       SwingUtilities.invokeAndWait(new SetterHostIntoWsdlFileThread(fileWSDLRD,fileWSDLWR));
       updateBar(35);

       this.ta.append("8) copia del file locator.xml nella webApp dell'Applicazione A..."+LF);
       // Patch 01/07/2003 - Nota N.21 Rel 1.1.
       inputFile = new File(currentDir + "/config/locator.xml");
       outputFile = new File(currentDir + "/classes/it/mokabyte/eai/my/config/locator.xml");
       SwingUtilities.invokeAndWait(new KopyFileThread(inputFile,outputFile));
       updateBar(40);

       // ======< EXEC >=====
       int choice = JOptionPane.YES_OPTION;
       if(new File(currentDir + File.separator+"bin").exists()){
                             choice = javax.swing.JOptionPane.showConfirmDialog(null,
                                 "Rebuild classes and jar?", "choose one", JOptionPane.YES_NO_OPTION);
       }

       if (choice == JOptionPane.YES_OPTION) {
           this.ta.append("8) esecuzione del builder"+extension+" ...please wait..."+LF);
           ExecutorThread execThread=new ExecutorThread();
           SwingUtilities.invokeAndWait(execThread);
           updateBar(100);
           this.ta.append("Configurazione terminata."+LF);

           // check its exit value
           if (execThread.getProcExitValue() != 0) {
              String msg = "CONFIGURAZIONE terminata in modo anomalo";
              javax.swing.JOptionPane.showMessageDialog(null, msg,
                             "Console Config",
                             javax.swing.JOptionPane.ERROR_MESSAGE);
              this.ta.append(msg+LF);
           }
           else {
             String msg = "Configurazione avvenuta con successo!";
             javax.swing.JOptionPane.showMessageDialog(null, msg,
                             "Console Config",
                             javax.swing.JOptionPane.INFORMATION_MESSAGE);
             this.ta.append(msg+LF);
         }
       }
       else{
         updateBar(100);
         String msg = "Configurazione terminata!";
                         javax.swing.JOptionPane.showMessageDialog(null, msg,
                         "Console Config",
                         javax.swing.JOptionPane.INFORMATION_MESSAGE);
         this.ta.append(msg+LF);
       }

       this.ta.append("Chiudere la finestra ..."+LF);
       this.ta.append(LF+"(*)Per effettuare il deploy  eseguire il batch [" + currentDir + File.separator+"ant"+File.separator+"deployer"+extension+"]"+LF);

     }
     catch (Exception e) {
         e.printStackTrace();
     }
     System.out.println("Finished on " + Thread.currentThread());
   }

   private void updateBar(int i){
     this.bar.setValue(i);
     this.label.setText(""+i+"%");
     if(i==100){
       Toolkit.getDefaultToolkit().beep();
     }
     try{ Thread.sleep(1000);}catch(InterruptedException ie){}
   }

   public boolean getStatus(){
     return true;
   }
 } // fine classe ConfiguratorMasterThread

 /**
  * <p>Title: KreatorScriptFileThread</p>
  * <p>Description: responsabile di creare i file di script</p>
  * <p>Copyright: Copyright (c) 2002</p>
  * <p>Company: </p>
   * @authorS. Rossini
  * @version 1.0
  */
  class KreatorScriptFileThread extends Thread{

    private File outputFile = null;
    private File inputFile = null;

    public KreatorScriptFileThread(File in, File out){
      System.out.println("KreatorScriptFileThread:...");
      this.inputFile=in;
      this.outputFile=out;
    }

    public void run() {
      try {
        createScriptFile(this.inputFile,this.outputFile);
      }
      catch (Exception e) {
         e.printStackTrace();
      }
    }

  } // fine classe KreatorScriptFileThread

  /**
   * <p>Title: KreatorScriptFileThread</p>
   * <p>Description: responsabile di creare i file di script</p>
   * <p>Copyright: Copyright (c) 2002</p>
   * <p>Company: </p>
    * @authorS. Rossini
   * @version 1.0
   */
   class KopyFileThread extends Thread{

     private File outputFile = null;
     private File inputFile = null;

     public KopyFileThread(File in, File out){
       System.out.println("KopierFileThread:...");
       this.inputFile=in;
       this.outputFile=out;
     }

     public void run() {
       try {
         copyFile(this.inputFile,this.outputFile);
       }
       catch (Exception e) {
          e.printStackTrace();
       }
     }

   } // fine classe KreatorScriptFileThread

  /**
   * <p>Title: KreatorScriptFileThread</p>
   * <p>Description: responsabile di creare i file di script</p>
   * <p>Copyright: Copyright (c) 2002</p>
   * <p>Company: </p>
   * @authorS. Rossini
   * @version 1.0
   */
   class KreatorPropertiesFileThread extends Thread{

     private File file = null;
     private boolean b;

     public KreatorPropertiesFileThread(File f,boolean b){
       System.out.println("KreatorPropertiesFileThread:...");
       this.file=f;
       this.b=b;
     }

     public void run() {
       try {
         createPropertiesFile(this.file,this.b);
       }
       catch (Exception e) {
          e.printStackTrace();
       }
     }

  } // fine classe KreatorPropertiesFileThread

  /**
   * <p>Title: KreatorScriptFileThread</p>
   * <p>Description: responsabile di creare i file di script</p>
   * <p>Copyright: Copyright (c) 2002</p>
   * <p>Company: </p>
   * @authorS. Rossini
   * @version 1.0
   */
  class SetterHostIntoWsdlFileThread extends Thread{

    private File outputFile = null;
    private File inputFile = null;

    public SetterHostIntoWsdlFileThread(File in, File out){
       System.out.println("KreatorScriptFileThread:...");
       this.inputFile=in;
       this.outputFile=out;
   }

   public void run() {
     try {
       setHostIntoWsdlFile(inputFile,outputFile);
     }
     catch (Exception e) {
        e.printStackTrace();
     }
   }

 } // fine classe SetterHostIntoWsdlFileThread

 /**
   * <p>Title: KreatorScriptFileThread</p>
   * <p>Description: responsabile di creare i file di script</p>
   * <p>Copyright: Copyright (c) 2002</p>
   * <p>Company: </p>
   * @authorS. Rossini
   * @version 1.0
   */
  class ExecutorThread extends Thread{

    private File outputFile = null;
    private File inputFile = null;
    private int procExitValue;

    public ExecutorThread(){
       System.out.println("ExecutorThread:...");
     }

   public void run() {
     try {
       this.procExitValue = callExec();
     }
     catch (Exception e) {
        e.printStackTrace();
     }
   }

   public int getProcExitValue(){
     return this.procExitValue;
   }
 } // fine classe SetterHostIntoWsdlFileThread

} // fine classe ConfiguratorConsole