package it.mokabyte.eai.my.client;

import java.io.*;

import it.mokabyte.eai.my.delegate.MyBusinessDelegate;
import it.mokabyte.eai.my.exception.BusinessDelegateException;
import it.mokabyte.eai.my.valueobject.ResultOM;
import it.mokabyte.eai.my.valueobject.MailOM;

import it.mokabyte.eai.my.client.TestClientDefines;
/**
 * <p>Title: BusinessDelegateTestClient </p>
 * <p>Description: client di test del Business Delegate</p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: </p>
 * @author S. Rossini
 * @version 1.0
 */
public class BusinessDelegateTestClient {

  private static final int ALL = -1;

  private static final String HEADER  = "\n\n\n\t\t";
  private static final String FOOTER = "\n\n\n";

  private static final String[] TEST_NAMES={
      "Test 0: concatenazione stringhe: EJB Concat JBOSS ...................(articolo 2)",
      "Test 1: calcolo lunghezza stringa: EJB Calculator WLS ...............(articolo 2)",
      "Test 2: concatenazione + calcolo lunghezza stringa: EJB Facade JBOSS (articolo 2)",
      "Test 3: calcolo lunghezza stringa: CORBA ORB SUN ....................(articolo 3)",
      "Test 4: calcolo lunghezza stringa: CORBA ORB MICO ...................(articolo 3)",
      "Test 5: calcolo lunghezza stringa: JMS ..............................(articolo 4)",
      "Test 6: calcolo lunghezza stringa: WebService AXIS ..................(articolo 4)" // ,
  //    "Test 7: calcolo lunghezza stringa: WebService .NET ..................(articolo 5)"
  };

  // propriet MyBusinessDelegate
  private MyBusinessDelegate proxy = null;

  /**
   * main
   * @param args
   */
  public static void main(String[] args) {
   new BusinessDelegateTestClient().test();
 }

  private static void displayTest(){
    System.out.println("+=============================================================================================+");
    System.out.println("| Selezionare il numero del test d'interesse (-1 per eseguire tutti i test, exit per uscire): | ");
    System.out.println("+=============================================================================================+");
    System.out.println("> I test verificano la concatenzaione della string["+TestClientDefines.PARAM_1+"] alla stringa ["+TestClientDefines.PARAM_2+"] & ");
    System.out.println("> il calcolo della lunghezza della stringa ["+TestClientDefines.PARAMS_CONCATENATED+"] che deve essere ["+TestClientDefines.LUNGHEZZA+"].....");
    System.out.println("===============================================================================================");
    for(int i=0; i<TEST_NAMES.length; ++i){
      System.out.println("["+i+"] - " +TEST_NAMES[i]);
    }
  }

  /**
   * <li> use MyBusinessDelegate to use the "hidden" Facade
   * <li> invoke business methods
   * @param userid
   */
  public void test() {

    // Visualizzazione dell configurazione del ServiceLocator
    try {
	it.mokabyte.eai.my.locator.MyServiceLocator.printConfiguration();
    }catch (Exception e) {
      System.out.println("Test Visualizzazione configurazione ServiceLocator fallito!");
    }

    while (true) {
        // lancio del test
        this.launchTest(this.readTestIndex());
    }
  }

  private void launchTest(int param) {

    this.proxy = new MyBusinessDelegate(); // costruzione del Business Delegate

    switch (param) { // switch sull'indice del test
      case 0:
        System.out.println(HEADER + "===>" + TEST_NAMES[0] + FOOTER);
        test0();
        break;

      case 1:
        System.out.println(HEADER + "===>" + TEST_NAMES[1] + FOOTER);
        test1();
        break;

      case 2:
        System.out.println(HEADER + "===>" + TEST_NAMES[2] + FOOTER);
        test2();
        break;

      case 3:
        System.out.println(HEADER + "===>" + TEST_NAMES[3] + FOOTER);
        test3();
        break;

      case 4:
        System.out.println(HEADER + "===>" + TEST_NAMES[3] + FOOTER);
        test4();
        break;

      case 5:
        System.out.println(HEADER + "===>" + TEST_NAMES[5] + FOOTER);
        test5();
        break;

      case 6:
        System.out.println(HEADER + "===>" + TEST_NAMES[6] + FOOTER);
        test6();
      break;

      case 7:
        System.out.println(HEADER + "===>" + TEST_NAMES[7] + FOOTER);
        test7();
      break;


      case -1:
        System.out.println(HEADER + "===>" + TEST_NAMES[0] + FOOTER);
        test0();
        System.out.println(HEADER + "===>" + TEST_NAMES[1] + FOOTER);
        test1();
        System.out.println(HEADER + "===>" + TEST_NAMES[2] + FOOTER);
        test2();
        System.out.println(HEADER + "===>" + TEST_NAMES[3] + FOOTER);
        test3();
        System.out.println(HEADER + "===>" + TEST_NAMES[4] + FOOTER);
        test4();
        System.out.println(HEADER + "===>" + TEST_NAMES[5] + FOOTER);
        test5();
        System.out.println(HEADER + "===>" + TEST_NAMES[6] + FOOTER);
        test6();
        System.out.println(HEADER + "===>" + TEST_NAMES[7] + FOOTER);
        test7();
        break;
    }
  }

  /**
   * test0: test concatenazione Concat EJB JBoss
   * @param Concat
   * @return
   */
  private void test0(){
      try{
        String res=proxy.getConcat(TestClientDefines.PARAM_1,TestClientDefines.PARAM_2);
        TestClientDefines.displayResult(res);
      }
      catch(Exception e) {
        System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
      }
  }
  /**
   * test1: test calcoloo lunghezza stringa Calculator EJB Bea-WLS
   * @return
   */
  private void test1(){
      try{
        int res=proxy.getLength(TestClientDefines.PARAMS_CONCATENATED);
        TestClientDefines.displayResult(res);
      }
      catch(Exception e) {
        System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
      }
  }

  /**
   * test2: test calcoloo concatenazione + lunghezza stringa Calculator Facade JBoss
   * @return
   */
  private void test2(){
      try{
        ResultOM res=proxy.getResult(TestClientDefines.PARAM_1,TestClientDefines.PARAM_2);
        TestClientDefines.displayResult(res.getConcat());
        TestClientDefines.displayResult(res.getLength().intValue());
      }
      catch(Exception e) {
        System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
      }
  }

   /**
     * test3: test lunghezza stringa con CORBA Servant Java - ORB SUN
     * @return
     */
   private void test3(){
     try{
        int res=proxy.getLengthByCorbaSun(TestClientDefines.PARAMS_CONCATENATED);
        TestClientDefines.displayResult(res);
      }
      catch(Exception e) {
        System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
      }
   }

   /**
     * test4: test lunghezza stringa con CORBA Servant C++ - ORB MICO
     * @return
     */
   private void test4(){
       try{
          int res=proxy.getLengthByCorbaMico(TestClientDefines.PARAMS_CONCATENATED);
          TestClientDefines.displayResult(res);
        }
        catch(Exception e) {
          System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
        }
     }

  /**
    * test5: test lunghezza stringa con JMS
    * @return
    */
  private void test5(){
      try{
        proxy.getLengthByJMS(new MailOM("srossini@mokabyte.it","CIAO!"));
        System.out.println(TestClientDefines.SUCCESS+"(verificare ricezione email)..."+FOOTER);
      }
      catch(Exception e) {
        System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
      }
  }

  /**
    * test6: test lunghezza stringa con WS Axis
    * @return
    */
  private void test6(){
       try{
         int res=proxy.getLengthByWsAxis(TestClientDefines.PARAMS_CONCATENATED);
         TestClientDefines.displayResult(res);
       }
       catch(Exception e) {
         System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
       }
  }

  /**
   * test7: test lunghezza stringa con WS .NET
   * @return
   */
  private void test7(){
    try{
      int res=proxy.getLengthByWsDotNet(TestClientDefines.PARAMS_CONCATENATED);
      TestClientDefines.displayResult(res);
    }
    catch(Exception e) {
      System.out.println(TestClientDefines.FAILED + " ["+e.getMessage()+"]..."+FOOTER);
    }
  }

  /**
    * Legge da tastiera l'indice della squadra favorita
    * @exception IOException per problemi di IO
    */
  private static  int readTestIndex() {
     int res = 0;
     boolean bFound = false;
     try{
        while(bFound == false) {
             BufferedReader msgStream = new BufferedReader (new InputStreamReader(System.in));
             BusinessDelegateTestClient.displayTest();
             System.out.print("Selezionare>");
             String strSel = msgStream.readLine();
             if(strSel.equalsIgnoreCase("exit")){
               System.out.print("\n\n\t>>> exiting ... goodbye <<<\n\n");
               System.exit(0);
             }
             try {
               res = Integer.parseInt(strSel);
               if(res >= -1 && res < TEST_NAMES.length) {
                   bFound = true;
               }
             } catch(NumberFormatException nfe) {
                   System.out.println("Inserire un numero tra 0 e " + (TEST_NAMES.length -1) + " oppure -1 ...");
             }
       }
     }catch(IOException ioe) {
         System.err.println(ioe.getMessage());
     }
     return res;
   }

}