package it.mokabyte.eai.my.client.jms;

import javax.naming.*;
import java.util.Properties;
import javax.rmi.PortableRemoteObject;

// JMS
import javax.jms.*;

import it.mokabyte.eai.my.delegate.CalculatorBusinessDelegate;
import it.mokabyte.eai.my.locator.MyServiceLocator;
import it.mokabyte.eai.my.exception.ServiceLocationException;
import it.mokabyte.eai.my.exception.BusinessDelegateException;
import it.mokabyte.eai.my.valueobject.MailOM;
import it.mokabyte.eai.my.util.Defines;
import it.mokabyte.eai.my.util.SimpleTrace;

import it.mokabyte.eai.my.util.PublicLibraries;
/**
 * <p>Title: </p>
 * <p>Description: Semplice client di test dell'EJB Calculator deployato su WLS</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author S. Rossini
 * @version 1.0
 */
public class CalculatorTestClient {

  private static String EMAIL = "aaa@bbb.it"; // SOSTITUIRLO con la email d'interesse

  public void test() {

    try {
      //get naming context
      Context ctx = new InitialContext();

      PublicLibraries.printContextProperties(ctx);

      PublicLibraries.diplayContextContent(ctx);

      String qfName = "ConnectionFactory";
      String qName = "queue/MokaEaiQueue";

      System.out.println("CalculatorMessageTestClient.test: lookup ["+qfName+"]...");

      // Delegate to the Calculator MDB
      QueueConnectionFactory queueConnectionFactory =(QueueConnectionFactory)ctx.lookup(qfName);
      System.out.println(
          "CalculatorMessageTestClient.test: QueueConnectionFactory["+
          queueConnectionFactory+"]-class["+queueConnectionFactory.getClass().getName()+"]...");
      QueueConnection queueConnection =
          queueConnectionFactory.createQueueConnection();
      QueueSession queueSession = queueConnection.createQueueSession(false,Session.AUTO_ACKNOWLEDGE);
      Queue queue = (Queue) ctx.lookup(qName);
      System.out.println("CalculatorTestClient.test: queue[" + queue +
          "]-class[" + queue.getClass().getName() + "]...");
      QueueSender queueSender = queueSession.createSender(queue);
      ObjectMessage messageToQueue = queueSession.createObjectMessage();
      MailOM mail = new MailOM(EMAIL,
                               it.mokabyte.eai.my.client.TestClientDefines.PARAMS_CONCATENATED);
      messageToQueue.setObject(mail);

      // La coda su cui ricevere la risposta JMS
      Queue queue_RX = (Queue) ctx.lookup("queue/MokaEaiQueue_RX");
      // set della coda di risposta nel messaggio da inviare
      messageToQueue.setJMSReplyTo(queue_RX);
      // invio del messaggio
      queueSender.send(messageToQueue);
      SimpleTrace.trace("CalculatorTestClient.test: messaggio ["+messageToQueue+"] inviato...");

      // creazione del ricevitore
      QueueReceiver queueReceiver = queueSession.createReceiver(queue_RX);

      SimpleTrace.trace("CalculatorTestClient.test: queueReceiver[" + queueReceiver + "]...");

      // avvio connessione
      queueConnection.start();

      // Ricezine asincrona: listener JMS
      // queueReceiver.setMessageListener(new MyListener());

      // Ricezione sincrona: 5 tentativi con timeout di 1 secondo ciascuno
      int i=0;
      for(i=0; i<5; ++i) {
          System.out.println("CalculatorTestClient.test: attesa di 1 sec. per ricevere il messaggio....");
          Message m = queueReceiver.receive(1000);
          if (m != null) {
              if (m instanceof TextMessage) {
                  TextMessage message = (TextMessage) m;
                  SimpleTrace.trace("CalculatorTestClient.test: messaggio ricevuto[" + message.getText() + "]");
                  break;
                }
          }
      }

      if(i==5){
        SimpleTrace.trace("CalculatorTestClient.test: TIMEOUT expired !");
      }

      queueConnection.close();
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }

  //Main method
  public static void main(String[] args) {
    System.out.println("starting CalculatorTestClient ...");
    new CalculatorTestClient().test();
  }

}

/* Listener asincrono JMS
 class MyListener implements MessageListener {

     public void onMessage(Message message) {
          . . .
     }
 }
*/
