package it.mokabyte.eai.my.delegate;

// EJB
import javax.ejb.CreateException;
import java.rmi.RemoteException;

// Moka includes (Application A)
import it.mokabyte.eai.my.ejb.ConcatHome;
import it.mokabyte.eai.my.ejb.Concat;
import it.mokabyte.eai.my.ejb.FacadeHome;
import it.mokabyte.eai.my.ejb.Facade;
import it.mokabyte.eai.my.valueobject.ResultOM;
import it.mokabyte.eai.my.locator.MyServiceLocator;
import it.mokabyte.eai.my.exception.ServiceLocationException;
import it.mokabyte.eai.my.exception.BusinessDelegateException;
import it.mokabyte.eai.my.valueobject.MailOM;
import it.mokabyte.eai.my.util.Defines;
import it.mokabyte.eai.my.util.SimpleTrace;
 /**
  * <p>Title: MyBusinessDelegate </p>
  * <p>Description: Business Delegate Applicazione A</p>
  * <p>Copyright: Copyright (c) 2003</p>
  * <p>Company: </p>
  * @author S. Rossini
  * @version 1.0
  */
public class MyBusinessDelegate{

  /** Il Remote reference del ConcatBean */
  private Concat concat = null;

  /** Il Remote reference dell'EJB Facade */
  private Facade facade = null;

  /**
   * Constructor
   * @throws ServiceLocationException
   */
  public MyBusinessDelegate() {
    SimpleTrace.trace("MyBusinessDelegate::MyBusinessDelegate: ...");
  }

 /**
  * Richiede la concatenzaione delle stinghe
  * @return le stringhe concatenate
  * @throws BusinessDelegateException
  */
  public String getConcat(String param1,String param2) throws BusinessDelegateException {

    // ################################### Articolo 2 ######################################

    // Delegate to the Concat EJB
    try {
      if(this.concat==null){
        SimpleTrace.trace("MyBusinessDelegate::MyBusinessDelegate : ...");
        ConcatHome homeConcat = (ConcatHome)MyServiceLocator.getEjbHome(Defines.SERVICE_CONCAT);
        SimpleTrace.trace("MyBusinessDelegate::MyBusinessDelegate : homeConcat class["+homeConcat.getClass().getName()+"] ...");
        SimpleTrace.trace("MyBusinessDelegate::MyBusinessDelegate : homeConcat ["+homeConcat+"] ...");
        this.concat= homeConcat.create();
      }
      SimpleTrace.trace("MyBusinessDelegate.getConcatResult: param1["+param1+"] - param2["+param2+"]...");
      return this.concat.concatTheString(param1,param2);
    } catch(CreateException ce){
        ce.printStackTrace();
        throw new BusinessDelegateException(ce);
    } catch(ServiceLocationException sle){
        sle.printStackTrace();
        throw new BusinessDelegateException(sle);
    } catch (RemoteException re) {
        re.printStackTrace();
        throw new BusinessDelegateException(re);
    }
  }

  /**
   * Richiede la concatenzaione delle stinghe ed il calcolo della lunghezza e l'array
   * @return l'object model
   * @throws BusinessDelegateException
   */
   public ResultOM getResult(String param1,String param2) throws BusinessDelegateException {

     // Delegate to the Facade EJB
     try {
       if(this.facade==null){
         SimpleTrace.trace("MyBusinessDelegate::MyBusinessDelegate : ...");
         FacadeHome home = (FacadeHome)MyServiceLocator.getEjbHome(Defines.SERVICE_FACADE);
         SimpleTrace.trace("MyBusinessDelegate::MyBusinessDelegate : homeConcat class["+home.getClass().getName()+"] ...");
         SimpleTrace.trace("MyBusinessDelegate::MyBusinessDelegate : homeConcat ["+home+"] ...");
         this.facade= home.create();
       }
       SimpleTrace.trace("MyBusinessDelegate.getResult: param1["+param1+"] - param2["+param2+"]...");
       return this.facade.getResult(param1,param2);
     } catch(CreateException ce){
         ce.printStackTrace();
         throw new BusinessDelegateException(ce);
     } catch(ServiceLocationException sle){
         sle.printStackTrace();
         throw new BusinessDelegateException(sle);
     } catch (RemoteException re) {
         re.printStackTrace();
         throw new BusinessDelegateException(re);
     }
  }

  /**
   * Richiede il calcolo della lunghezza della stringa
   * param la stringa di cui calcolare la lunghezza
   * @return la lunghezza della stringa param
   * @throws BusinessDelegateException
   */
   public int getLength(String param) throws BusinessDelegateException {
     return this.getPluginProxy("it.mokabyte.eai.my.delegate.ejb.CalculatorBdEJBImpl").getLength(param);
   }

  // ################################### Articolo 3 ######################################

  /**
    * This method get the string length of the parameter
    * @return
    * @throws BusinessDelegateException
    */
  public int getLengthByCorbaSun(String param) throws BusinessDelegateException {
    return this.getPluginProxy("it.mokabyte.eai.my.delegate.corba.CalculatorBdCORBAImpl",new Integer(Defines.SERVICE_CALCULATOR_CORBA_SUN)).getLength(param);
  }

  /**
     * This method get the string length of the parameter
     * @return
     * @throws BusinessDelegateException
     */
   public int getLengthByCorbaMico(String param) throws BusinessDelegateException {
     return this.getPluginProxy("it.mokabyte.eai.my.delegate.corba.CalculatorBdCORBAImpl",new Integer(Defines.SERVICE_CALCULATOR_CORBA_MICO)).getLength(param);
   }

  // ################################### Articolo 4 ######################################

  /**
    * This method get the string length of the parameter
    * @return
    * @throws BusinessDelegateException
    */
  public void getLengthByJMS(MailOM param) throws BusinessDelegateException {
    this.getPluginProxy("it.mokabyte.eai.my.delegate.jms.CalculatorBdJMSImpl",param).getLength(param.getBodyMail());
  }

  /**
    * Usa le classi stub ottenuto dal tool WSDL2Java per invocare un WS AXIS
    * @return lunghezza della stringa ricevuta come parametro
    * @throws BusinessDelegateException
    */
  public int getLengthByWsAxis(String param)throws BusinessDelegateException {
   return this.getPluginProxy("it.mokabyte.eai.my.delegate.ws.axis.CalculatorBdWSImpl").getLength(param);
  }

  // ################################### Articolo 5 ######################################

  /**
    * Usa le classi stub ottenuto dal tool WSDL2Java per invocare un WS .NET
    * @return lunghezza della stringa ricevuta come parametro
    * @throws BusinessDelegateException
    */
  public int getLengthByWsDotNet(String param)throws BusinessDelegateException {
    return this.getPluginProxy("it.mokabyte.eai.my.delegate.ws.dotnet.CalculatorBdWSImpl").getLength(param);
  }

  // ####################################### utility ######################################

  /** load plugin proxy by class name */
  private CalculatorBusinessDelegate getPluginProxy(String className)throws BusinessDelegateException{
    try{
       SimpleTrace.trace("MyBusinessDelegateException.getProxy: loading class["+className+"]...");
       CalculatorBusinessDelegate res=(CalculatorBusinessDelegate) Class.forName(className).newInstance();
       SimpleTrace.trace("MyBusinessDelegateException.getProxy: loaded ! Class["+res.getClass().getName()+"]...");
       return res;
     }catch(Exception e){
         SimpleTrace.trace(" # Exception # MyBusinessDelegateException.getProxy: " + e.getMessage());
         e.printStackTrace();
         throw new BusinessDelegateException(e);
      }
  }

  /** load plugin proxy by class name and an Object with parameter */
  private CalculatorBusinessDelegate getPluginProxy(String className, Object param)throws BusinessDelegateException{
    try{
       SimpleTrace.trace("MyBusinessDelegateException.getProxy: loading class["+className+"]...");
       java.lang.reflect.Constructor[] constructors=Class.forName(className).getConstructors();
       Object[] objs={ param };
       CalculatorBusinessDelegate res=(CalculatorBusinessDelegate)constructors[0].newInstance(objs);
       SimpleTrace.trace("MyBusinessDelegateException.getProxy: loaded ! Class["+res.getClass().getName()+"]...");
       return res;
    }catch(Exception e){
       SimpleTrace.trace(" # Exception # MyBusinessDelegateException.getProxy: " + e.getMessage());
       e.printStackTrace();
       throw new BusinessDelegateException(e);
    }
  }


}