package it.mokabyte.eai.my.ejb;

import java.util.Properties;

import java.rmi.RemoteException;

import javax.rmi.PortableRemoteObject;

import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.ejb.CreateException;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import it.mokabyte.eai.my.ejb.ConcatHome;
import it.mokabyte.eai.my.ejb.Concat;

//import it.mokabyte.eai.other.ejb.CalculatorHome;
//import it.mokabyte.eai.other.ejb.Calculator;

import it.mokabyte.eai.my.ejb.CalculatorHome;
import it.mokabyte.eai.my.ejb.Calculator;

import it.mokabyte.eai.my.valueobject.ResultOM;
/**
 * <p>Title: FacadeBean</p>
 * <p>Ejb Facade dell'EJB Concat(JBoss) & Calculator(WLS)</p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: </p>
 * @author S.Rossini
 * @version 1.0
 */
public class FacadeBean implements SessionBean {

  // Configurazione per localizzare gli EJB(esternalizzare nel MyServiceLocator)
  // Concat
  private static final String JBOSS_CTX_FACTORY ="org.jnp.interfaces.NamingContextFactory";
  private static final String JBOSS_PROVIDER_URL = "jnp://localhost:1099";
  private static final String CONCAT_JNDI_NAME = "java:comp/env/ejb/Concat";

  private static final String CALCULATOR_JNDI_NAME = "MokaCalculator";

  // Il weblogic.jar necessario per comunicare con WLS non permette il deploy di EJB
  // in IIOP con JBoss 3.0.7.
  // Da verificare se anche con JBoss 3.2.1 e JBoss 4
  // Calculator WLS
  // private static final String WLS_CTX_FACTORY ="weblogic.jndi.WLInitialContextFactory";
  // private static final String WLS_PROVIDER_URL = "t3://localhost:7001";
  // private static final String CALCULATOR_JNDI_NAME = "MokaCalculatorWLS";

  /**
   * getResult
   * @param a stringa da concatenare
   * @param b stringa da concatenare
   * @return l'object model relativa all'elaborazione dibusiness
   * @throws RemoteException
   */
  public ResultOM getResult(String a, String b) throws RemoteException {
    try{
      ResultOM result = new ResultOM();
      System.out.println("Facade.getResult: ...");

      // concat
      String strResult=this.getConcat(a, b);
      System.out.println("Facade.getResult: concat done: result["+strResult+"]...");

      // length
      int iResult=this.getLength(strResult);
      System.out.println("Facade.getResult: calculator done: result["+iResult+"]...");

      // Extra business logic
      result.setConcat(new java.util.Date().toString()+":"+strResult);
      result.setLength(new Integer(iResult));

      // Return result
      System.out.println("Facade.getResult: returning result["+result+"]...");
      return result;

   }catch(Exception e){
      System.out.println(" # Exception # Facade.getResult: "+e.getMessage());
      e.printStackTrace();
      throw new RemoteException(e.getMessage());
   }
  }

  private String getConcat(String a, String b) throws NamingException,CreateException,RemoteException {
      Properties properties = new Properties();
      properties.put(Context.INITIAL_CONTEXT_FACTORY, JBOSS_CTX_FACTORY);
      properties.put(Context.PROVIDER_URL, JBOSS_PROVIDER_URL);
      Context ctx = new InitialContext(properties);
      System.out.println("Facade.getConcat: ctx ["+ctx+"]...");
     //look up jndi name
      System.out.println("Facade.getConcat: Lookup of ["+CONCAT_JNDI_NAME+"]...");
      Object ref = ctx.lookup(CONCAT_JNDI_NAME);
      System.out.println("Facade.getConcat: Lookup done: obj["+ref +"]-class["+ref.getClass().getName() + "]...");
      //cast to Home interface
      ConcatHome home = (ConcatHome) PortableRemoteObject.narrow(ref,ConcatHome.class);
      System.out.println("Facade.getConcat: narrow done: home["+home+"]-class["+home.getClass().getName() + "]...");
      Concat concat = home.create();
      System.out.println("Facade.getConcat: create done: concat["+concat+"]-class["+concat.getClass().getName() + "]...");
      String result = concat.concatTheString(a,b);
      System.out.println("Facade.getConcat: result["+result+ "]...");
      return result;
  }

  private int getLength(String a) throws NamingException,CreateException,RemoteException {
      Properties properties = new Properties();
      properties.put(Context.INITIAL_CONTEXT_FACTORY, JBOSS_CTX_FACTORY);
      properties.put(Context.PROVIDER_URL, JBOSS_PROVIDER_URL);
      Context ctx = new InitialContext(properties);
      System.out.println("Facade.getLength: ctx ["+ctx+"]...");
      //look up jndi name
      System.out.println("Facade.getLength: Lookup of["+CALCULATOR_JNDI_NAME+"]...");
      Object ref = ctx.lookup(CALCULATOR_JNDI_NAME);
      System.out.println("Facade.getLength: Lookup done: obj["+ref+"]-class["+ref.getClass().getName() + "]...");
      //cast to Home interface
      CalculatorHome home = (CalculatorHome) PortableRemoteObject.narrow(ref,CalculatorHome.class);
      System.out.println("Facade.getLength: narrow done: home["+home+"]-class["+home.getClass().getName() + "]...");
      Calculator calc = home.create();
      System.out.println("Facade.getLength: create done: calc["+calc+"]-class["+calc.getClass().getName() + "]...");
      int result=calc.getStringLength(a);
      System.out.println("Facade.getLength: result["+result+"]...");
      return result;
  }

  public FacadeBean() {
      System.out.println(new java.util.Date().toString()+"-FacadeBean::constructor...");
  }
  public void ejbCreate() {
      System.out.println(new java.util.Date().toString()+"-FacadeBean.ejbCreate...");
  }
  public void ejbRemove() {
      System.out.println(new java.util.Date().toString()+"-FacadeBean.ejbRemove...");
  }
  public void ejbActivate() {
      System.out.println(new java.util.Date().toString()+"-FacadeBean.ejbActivate...");
  }
  public void ejbPassivate() {
      System.out.println(new java.util.Date().toString()+"-FacadeBean.ejbPassivate...");
  }
  public void setSessionContext(SessionContext sc) {
      System.out.println(new java.util.Date().toString()+"-FacadeBean.setSessionContext(ctx)...");
  }
}
