package it.mokabyte.eai.my.webservices;

import javax.naming.*;
import javax.ejb.*;
import javax.rmi.*;
import java.util.*;

import it.mokabyte.eai.my.ejb.CalculatorHome;
import it.mokabyte.eai.my.ejb.Calculator;
/**
 * <p>Title: MyCalculatorService </p>
 * <p>Description: semplice Web Service Wrapper dell'EJB Calculator</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author S. Rossini
 * @version 1.0
 */
public class CalculatorService {

  // SUN RI Connection Factory class   : "com.sun.jndi.cosnaming.CNCtxFactory"
  // JBoss Connection Factory class    : "org.jnp.interfaces.NamingContextFactory"
  // WebLogic Connection Factory class : "weblogic.jndi.WLInitialContextFactory"

  // SUN RI URL   : "iiop://localhost:1050";
  // JBoss URL    : "jnp://localhost:1099";
  // WebLogic URL : "t3://localhost:7001"

  // Configurazione per localizzare l'EJB
  private static final String CTX_FACTORY = "org.jnp.interfaces.NamingContextFactory";
  private static final String PROVIDER_URL = "jnp://localhost:1099";
  private static final String JNDI_NAME = "MokaCalculator";

  /**
   * Costruttore
   */
  public CalculatorService() {
    System.out.println(new java.util.Date().toString() + ":CalculatorService: constructor ...");
  }

  /**
   * Il metodo di business
   * @param s
   * @return la lunghezza della stringa
   */
  public int getLength(String arg) {

    System.out.println(new java.util.Date().toString() + "-CalculatorService.getLength: args["+arg+"]...");

    int result = -1;

    try {
        Properties properties = new Properties();
        properties.put(Context.INITIAL_CONTEXT_FACTORY, CTX_FACTORY);
        properties.put(Context.PROVIDER_URL, PROVIDER_URL);
        Context ctx = new InitialContext(properties);
        System.out.println("CalculatorService.getLength: ctx ["+ctx+"]...");

        //look up jndi name
        System.out.println("CalculatorService.getLength: Lookup of ["+JNDI_NAME+"]...");

        Object ref = ctx.lookup(JNDI_NAME);
        System.out.println("CalculatorService.getLength: Lookup done : obj["+ref+"]...");
        System.out.println("CalculatorService.getLength: Lookup done : obj class["+ref.getClass().getName()+"]...");

        //cast to Home interface
        CalculatorHome home = (CalculatorHome) PortableRemoteObject.narrow(ref, CalculatorHome.class);
        System.out.println("CalculatorService.getLength: Narrow done : home["+home+"]...");
        System.out.println("CalculatorService.getLength: Narrow done : home class["+home.getClass().getName()+"]...");

        Calculator calc = home.create();

        result = calc.getStringLength(arg);
        System.out.println("CalculatorService.getLength: returning ["+result+"]...");
    }
    catch(Exception ex) {
        System.out.println(" ### Exception ! CalculatorService:" + ex.getMessage());
        ex.printStackTrace();
    }

    System.out.println("CalculatorService.getLength: returning result["+result+"]...");
    return result;
  }

}
