// file mainClient.cc
// Author: Alberto D'Angeli
//

#include <iostream>
#include <fstream>
#include <stdlib.h>

#include <CORBA.h>
#include <coss/CosNaming.h>
#include "calcolatrice.h"


#include "Calculator.nsmap"
#include "soapH.h"
#include <string.h> 

using namespace std;

static CORBA::ORB_var orb;

int main(int argc, char* argv[])
{

    try {
        // Initialize the ORB.
       orb = CORBA::ORB_init(argc, argv);
    }
    catch(const CORBA::Exception& e) {
        cerr << e << endl;
        return 1;
    }

   struct soap soap;
   int m, s; // master and slave sockets
   soap_init(&soap);
   m = soap_bind(&soap, argv[1], atoi(argv[2]), 100);
   if (m < 0)
       soap_print_fault(&soap, stderr);
   else
   {
       fprintf(stderr, "Socket connection successful: master socket = %d\n", m);
       for (int i = 1; ; i++)
       {
           s = soap_accept(&soap);
           if (s < 0)
	   {
              soap_print_fault(&soap, stderr);
              break;
          }
          fprintf(stderr, "%d: accepted connection from IP=%lu.%lu.%lu.%lu socket=%d", i,
              (soap.ip << 24)&0xFF, (soap.ip << 16)&0xFF, (soap.ip << 8)&0xFF, soap.ip&0xFF, s);
          soap_serve(&soap); // process RPC request
          fprintf(stderr, "request served\n");
          soap_destroy(&soap); // clean up class instances
          soap_end(&soap); // clean up everything and close socket
      }
    }
    soap_done(&soap); // close master socket
}

// Implementation of the "getLength" remote method:
int impl__getLength(struct soap *soap, xsd__string arg, impl__getLengthResponse* out)
{
	
    fprintf(stderr, "\ngetLength implementation called\n");
    fprintf(stderr, "\nwith argument %s\n", arg);

    try {

       CosNaming::NamingContext_var rootContext = CosNaming::NamingContext::_narrow(orb->resolve_initial_references("NameService"));

       CosNaming::Name name;
       name.length(2);
       name[0].id = (const char *) "eai";
       name[0].kind = (const char *) "";
       name[1].id = (const char *) "calcolatrice";
       name[1].kind = (const char *) "";

       CORBA::Object_var object = rootContext->resolve(name);

       // Locate a calcolatrice manager . Give the full POA name and the servant ID.
       eai::Calcolatrice_var manager =  eai::Calcolatrice::_narrow(object.in());
       CORBA::String_var msg = CORBA::string_dup(arg);
       out->_getLengthReturn  = manager->strlen_calc(msg.in());
       cout << " Lunghezza di " << msg.in() << " = " << out->_getLengthReturn << endl;

    }
    catch(const CORBA::Exception& e) {
          cerr << e << endl;
          return 1;
    }

    //out->_getLengthReturn  = strlen(arg);
    return SOAP_OK;
}
